import { pTokensSwap } from './ptokens-swap';
import { validators } from 'ptokens-helpers';
import BigNumber from 'bignumber.js';
export class pTokensSwapBuilder {
    constructor(node) {
        this._destinationAssets = [];
        this._node = node;
    }
    get sourceAsset() {
        return this._sourceAsset;
    }
    get destinationAssets() {
        return this._destinationAssets.map((_el) => _el.asset);
    }
    get amount() {
        return this._amount.toFixed();
    }
    get node() {
        return this._node;
    }
    setSourceAsset(asset) {
        this._sourceAsset = asset;
        return this;
    }
    addDestinationAsset(asset, destinationAddress, userData = undefined) {
        const isValidAddressFunction = validators.chainIdToAddressValidatorMap.get(asset.chainId);
        if (!isValidAddressFunction(destinationAddress))
            throw new Error('Invalid destination address');
        this._destinationAssets.push({ asset, destinationAddress, userData });
        return this;
    }
    setAmount(_amount) {
        this._amount = BigNumber(_amount);
        return this;
    }
    build() {
        if (!this._amount)
            throw new Error('Missing amount');
        if (!this._sourceAsset)
            throw new Error('Missing source asset');
        if (this._destinationAssets.length === 0)
            throw new Error('Missing destination assets');
        if (!this.destinationAssets.every((_asset) => _asset.assetInfo.tokenReference.toLowerCase() === this.sourceAsset.assetInfo.tokenReference.toLowerCase()))
            throw new Error('Invalid swap');
        const ret = new pTokensSwap(this._node, this.sourceAsset, this._destinationAssets, this._amount);
        return ret;
    }
}
//# sourceMappingURL=ptokens-swap-builder.js.map